@@ -15,13 +15,13 @@ from z3c.pt.pagetemplate import PageTemplateFile as ChameleonPageTemplateFile
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from App.class_init import InitializeClass
 from Products.PageTemplates.Expressions import getEngine
-from RestrictedPython.Utilities import utility_builtins
 
 from chameleon.tales import StringExpr
 from chameleon.tales import NotExpr
-from chameleon.tales import PythonExpr
 from chameleon.tal import RepeatDict
 
+from z3c.pt.expressions import PythonExpr
+
 from .expressions import PathExpr
 from .expressions import TrustedPathExpr
 from .expressions import ProviderExpr
@@ -68,10 +68,8 @@ def cook(self):
 
     if engine is getEngine():
         expression_types = _secure_expression_types
-        builtins = utility_builtins
     else:
         expression_types = _expression_types
-        builtins = {}
 
     if filename is None:
         program = ChameleonPageTemplate(
@@ -84,8 +82,6 @@ def cook(self):
             expression_types=expression_types,
             encoding='utf-8')
 
-    program._v_builtins = builtins
-
     self._v_program = program
     self._v_macros = program.macros
     self._v_cooked = 1
@@ -128,9 +124,6 @@ class ChameleonTALInterpreter(object):
             context['wrapped_repeat'] = context['repeat']
             context['repeat'] = RepeatDict(self.repeat)
 
-            # Update context with applicable builtins
-            context.update(self.template._v_builtins)
-
             result = self.template.render(**context)
 
         self.stream.write(result)
