@@ -3,23 +3,37 @@ import unittest
 from Products.Five import BrowserView
 from Testing.ZopeTestCase import ZopeTestCase
 
-from five.pt.pagetemplate import ViewPageTemplateFile
+from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
+
 
 class SimpleView(BrowserView):
     index = ViewPageTemplateFile('simple.pt')
 
+
 class LocalsView(BrowserView):
     def available(self):
         return 'yes'
 
-    def tagsoup(self):
-        return '<foo></bar>'
-
     index = ViewPageTemplateFile('locals.pt')
 
+
 class OptionsView(BrowserView):
     index = ViewPageTemplateFile('options.pt')
 
+
+class SecureView(BrowserView):
+    index = ViewPageTemplateFile('secure.pt')
+
+    __allow_access_to_unprotected_subobjects__ = True
+
+    def tagsoup(self):
+        return '<foo></bar>'
+
+
+class MissingView(BrowserView):
+    index = ViewPageTemplateFile('missing.pt')
+
+
 class TestPageTemplateFile(ZopeTestCase):
     def afterSetUp(self):
         from Products.Five import zcml
@@ -35,6 +49,16 @@ class TestPageTemplateFile(ZopeTestCase):
         result = view.index()
         self.failUnless('Hello world!' in result)
 
+    def test_secure(self):
+        view = SecureView(self.folder, self.folder.REQUEST)
+        from zExceptions import Unauthorized
+        try:
+            result = view.index()
+        except Unauthorized:
+            self.fail("Unexpected exception.")
+        else:
+            self.failUnless('&lt;foo&gt;&lt;/bar&gt;' in result)
+
     def test_locals(self):
         view = LocalsView(self.folder, self.folder.REQUEST)
         result = view.index()
@@ -44,8 +68,8 @@ class TestPageTemplateFile(ZopeTestCase):
         self.failUnless('here==context:True' in result)
         self.failUnless('here==container:True' in result)
         self.failUnless("root:(\'\',)" in result)
-        self.failUnless("nothing:None" in result)
-        self.failUnless("modules:&lt;foo&gt;" in result)
+        self.failUnless("nothing:" in result)
+        self.failUnless("rfc822" in result)
 
     def test_options(self):
         view = OptionsView(self.folder, self.folder.REQUEST)
@@ -58,6 +82,23 @@ class TestPageTemplateFile(ZopeTestCase):
         self.failUnless("a : 1" in result)
         self.failUnless("c : abc" in result)
 
+    def test_MissingValue(self):
+        request = self.folder.REQUEST
+        view = MissingView(self.folder, request)
+
+        from zope.component import provideUtility
+        from zope.i18n.interfaces import ITranslationDomain
+        from zope.i18n.simpletranslationdomain import SimpleTranslationDomain
+        pfp = SimpleTranslationDomain('test', {})
+        provideUtility(pfp, ITranslationDomain, name='test')
+
+        import Missing
+        request["LANGUAGE"] = 'en'
+        result = view.index(missing=Missing.MV)
+        del request.other["LANGUAGE"]
+
+        self.failUnless('<span></span>' in result)
+
 
 def test_suite():
     import sys
